@@ -1,10 +1,9 @@
-# -*- coding: utf-8 -*-
-# Copyright (c) 2014-2019 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2014-2020 Claudiu Popa <pcmanticore@gmail.com>
 # Copyright (c) 2014 Michal Nowikowski <godfryd@gmail.com>
 # Copyright (c) 2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
 # Copyright (c) 2015 Pavel Roskin <proski@gnu.org>
 # Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
-# Copyright (c) 2016-2017 Pedro Algarvio <pedro@algarvio.me>
+# Copyright (c) 2016-2017, 2020 Pedro Algarvio <pedro@algarvio.me>
 # Copyright (c) 2016 Alexander Todorov <atodorov@otb.bg>
 # Copyright (c) 2017 Łukasz Rogalski <rogalski.91@gmail.com>
 # Copyright (c) 2017 Mikhail Fesenko <proggga@gmail.com>
@@ -12,9 +11,12 @@
 # Copyright (c) 2018 ssolanki <sushobhitsolanki@gmail.com>
 # Copyright (c) 2018 Mike Frysinger <vapier@gmail.com>
 # Copyright (c) 2018 Sushobhit <31987769+sushobhit27@users.noreply.github.com>
+# Copyright (c) 2019-2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2019 Peter Kolbus <peter.kolbus@gmail.com>
 # Copyright (c) 2019 agutole <toldo_carp@hotmail.com>
-# Copyright (c) 2019 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2020 Ganden Schaffner <gschaffner@pm.me>
+# Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2020 Damien Baty <damien.baty@polyconseil.fr>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
@@ -31,7 +33,7 @@ from pylint.interfaces import IAstroidChecker, ITokenChecker
 
 try:
     import enchant
-    from enchant.tokenize import (  # type: ignore
+    from enchant.tokenize import (
         Chunker,
         EmailFilter,
         Filter,
@@ -41,7 +43,16 @@ try:
     )
 except ImportError:
     enchant = None
-    # pylint: disable=no-init
+
+    class EmailFilter:  # type: ignore
+        ...
+
+    class URLFilter:  # type: ignore
+        ...
+
+    class WikiWordFilter:  # type: ignore
+        ...
+
     class Filter:  # type: ignore
         def _skip(self, word):
             raise NotImplementedError
@@ -49,23 +60,27 @@ except ImportError:
     class Chunker:  # type: ignore
         pass
 
+    def get_tokenizer(
+        tag=None, chunkers=None, filters=None
+    ):  # pylint: disable=unused-argument
+        return Filter()
+
 
 if enchant is not None:
     br = enchant.Broker()
     dicts = br.list_dicts()
     dict_choices = [""] + [d[0] for d in dicts]
-    dicts = ["%s (%s)" % (d[0], d[1].name) for d in dicts]
+    dicts = ["{} ({})".format(d[0], d[1].name) for d in dicts]
     dicts = ", ".join(dicts)
     instr = ""
 else:
     dicts = "none"
     dict_choices = [""]
-    instr = " To make it work, install the python-enchant package."
+    instr = " To make it work, install the 'python-enchant' package."
 
 
 class WordsWithDigigtsFilter(Filter):
-    """Skips words with digits.
-    """
+    """Skips words with digits."""
 
     def _skip(self, word):
         for char in word:
@@ -102,12 +117,12 @@ class SphinxDirectives(Filter):
     r"""Filter skipping over Sphinx Directives.
     This filter skips any words matching the following regular expression:
 
-           ^:([a-z]+):`([^`]+)(`)?
+           ^(:([a-z]+)){1,2}:`([^`]+)(`)?
 
     That is, for example, :class:`BaseQuery`
     """
     # The final ` in the pattern is optional because enchant strips it out
-    _pattern = re.compile(r"^:([a-z]+):`([^`]+)(`)?")
+    _pattern = re.compile(r"^(:([a-z]+)){1,2}:`([^`]+)(`)?")
 
     def _skip(self, word):
         return bool(self._pattern.match(word))
@@ -291,7 +306,7 @@ class SpellingChecker(BaseTokenChecker):
             initial_space = re.search(r"^[^\S]\s*", line).regs[0][1]
         except (IndexError, AttributeError):
             initial_space = 0
-        if line.strip().startswith("#"):
+        if line.strip().startswith("#") and "docstring" not in msgid:
             line = line.strip()[1:]
             starts_with_comment = True
         else:
@@ -335,7 +350,6 @@ class SpellingChecker(BaseTokenChecker):
                 # Present up to N suggestions.
                 suggestions = self.spelling_dict.suggest(word)
                 del suggestions[self.config.max_spelling_suggestions :]
-
                 line_segment = line[word_start_at:]
                 match = re.search(r"(\W|^)(%s)(\W|$)" % word, line_segment)
                 if match:
@@ -343,23 +357,13 @@ class SpellingChecker(BaseTokenChecker):
                     col = match.regs[2][0]
                 else:
                     col = line_segment.index(word)
-
                 col += word_start_at
-
                 if starts_with_comment:
                     col += 1
                 indicator = (" " * col) + ("^" * len(word))
-
-                self.add_message(
-                    msgid,
-                    line=line_num,
-                    args=(
-                        word,
-                        original_line,
-                        indicator,
-                        "'{}'".format("' or '".join(suggestions)),
-                    ),
-                )
+                all_suggestion = "' or '".join(suggestions)
+                args = (word, original_line, indicator, f"'{all_suggestion}'")
+                self.add_message(msgid, line=line_num, args=args)
 
     def process_tokens(self, tokens):
         if not self.initialized:
