@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 # Copyright (c) 2013-2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
 # Copyright (c) 2013-2014 Google, Inc.
-# Copyright (c) 2014-2019 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2014-2020 Claudiu Popa <pcmanticore@gmail.com>
 # Copyright (c) 2014 Cosmin Poieana <cmin@ropython.org>
 # Copyright (c) 2014 Vlad Temian <vladtemian@gmail.com>
 # Copyright (c) 2014 Arun Persaud <arun@nubati.net>
@@ -16,13 +15,18 @@
 # Copyright (c) 2018 Lucas Cimon <lucas.cimon@gmail.com>
 # Copyright (c) 2018 Banjamin Freeman <befreeman@users.noreply.github.com>
 # Copyright (c) 2018 Ioana Tagirta <ioana.tagirta@gmail.com>
+# Copyright (c) 2019-2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2019 Julien Palard <julien@palard.fr>
 # Copyright (c) 2019 laike9m <laike9m@users.noreply.github.com>
 # Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
 # Copyright (c) 2019 Robert Schweizer <robert_schweizer@gmx.de>
 # Copyright (c) 2019 fadedDexofan <fadedDexofan@gmail.com>
-# Copyright (c) 2019 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2020 Sorin Sbarnea <ssbarnea@redhat.com>
+# Copyright (c) 2020 Federico Bond <federicobond@gmail.com>
+# Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
+# Copyright (c) 2020 谭九鼎 <109224573@qq.com>
 # Copyright (c) 2020 Anthony Sottile <asottile@umich.edu>
+# Copyright (c) 2021 Matus Valo <matusvalo@gmail.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 # For details: https://github.com/PyCQA/pylint/blob/master/COPYING
@@ -32,10 +36,8 @@
 import sys
 
 import astroid
-from astroid.bases import Instance
-from astroid.node_classes import Const
 
-from pylint.checkers import BaseChecker, utils
+from pylint.checkers import BaseChecker, DeprecatedMixin, utils
 from pylint.interfaces import IAstroidChecker
 
 OPEN_FILES = {"open", "file"}
@@ -79,7 +81,7 @@ def _check_mode_str(mode):
     return True
 
 
-class StdlibChecker(BaseChecker):
+class StdlibChecker(DeprecatedMixin, BaseChecker):
     __implements__ = (IAstroidChecker,)
     name = "stdlib"
 
@@ -89,7 +91,7 @@ class StdlibChecker(BaseChecker):
             "bad-open-mode",
             "Python supports: r, w, a[, x] modes with b, +, "
             "and U (only with r) options. "
-            "See http://docs.python.org/2/library/functions.html#open",
+            "See https://docs.python.org/2/library/functions.html#open",
         ),
         "W1502": (
             "Using datetime.time in a boolean context.",
@@ -97,7 +99,7 @@ class StdlibChecker(BaseChecker):
             "Using datetime.time in a boolean context can hide "
             "subtle bugs when the time they represent matches "
             "midnight UTC. This behaviour was fixed in Python 3.5. "
-            "See http://bugs.python.org/issue13936 for reference.",
+            "See https://bugs.python.org/issue13936 for reference.",
             {"maxversion": (3, 5)},
         ),
         "W1503": (
@@ -214,6 +216,7 @@ class StdlibChecker(BaseChecker):
                 "base64.encodestring",
                 "base64.decodestring",
                 "ntpath.splitunc",
+                "os.path.splitunc",
             },
             (3, 2, 0): {
                 "cgi.escape",
@@ -247,6 +250,33 @@ class StdlibChecker(BaseChecker):
                 "platform.dist",
             },
             (3, 6, 0): {"importlib._bootstrap_external.FileLoader.load_module"},
+            (3, 7, 0): {
+                "sys.set_coroutine_wrapper",
+                "sys.get_coroutine_wrapper",
+                "aifc.openfp",
+                "asyncio.Task.current_task",
+                "asyncio.Task.all_task",
+                "locale.format",
+                "ssl.wrap_socket",
+                "sunau.openfp",
+                "wave.openfp",
+            },
+            (3, 8, 0): {
+                "gettext.lgettext",
+                "gettext.ldgettext",
+                "gettext.lngettext",
+                "gettext.ldngettext",
+                "gettext.bind_textdomain_codeset",
+                "gettext.NullTranslations.output_charset",
+                "gettext.NullTranslations.set_output_charset",
+                "threading.Thread.isAlive",
+            },
+            (3, 9, 0): {
+                "binascii.b2a_hqx",
+                "binascii.a2b_hqx",
+                "binascii.rlecode_hqx",
+                "binascii.rledecode_hqx",
+            },
         },
     }
 
@@ -307,7 +337,7 @@ class StdlibChecker(BaseChecker):
                         self._check_env_function(node, inferred)
                     elif name == SUBPROCESS_RUN:
                         self._check_for_check_kw_in_run(node)
-                self._check_deprecated_method(node, inferred)
+                self.check_deprecated_method(node, inferred)
         except astroid.InferenceError:
             return
 
@@ -329,37 +359,6 @@ class StdlibChecker(BaseChecker):
         for value in node.values:
             self._check_datetime(value)
 
-    def _check_deprecated_method(self, node, inferred):
-        py_vers = sys.version_info[0]
-
-        if isinstance(node.func, astroid.Attribute):
-            func_name = node.func.attrname
-        elif isinstance(node.func, astroid.Name):
-            func_name = node.func.name
-        else:
-            # Not interested in other nodes.
-            return
-
-        # Reject nodes which aren't of interest to us.
-        acceptable_nodes = (
-            astroid.BoundMethod,
-            astroid.UnboundMethod,
-            astroid.FunctionDef,
-        )
-        if not isinstance(inferred, acceptable_nodes):
-            return
-
-        qname = inferred.qname()
-        if any(name in self.deprecated[0] for name in (qname, func_name)):
-            self.add_message("deprecated-method", node=node, args=(func_name,))
-        else:
-            for since_vers, func_list in self.deprecated[py_vers].items():
-                if since_vers <= sys.version_info and any(
-                    name in func_list for name in (qname, func_name)
-                ):
-                    self.add_message("deprecated-method", node=node, args=(func_name,))
-                    break
-
     def _check_redundant_assert(self, node, infer):
         if (
             isinstance(infer, astroid.BoundMethod)
@@ -374,14 +373,17 @@ class StdlibChecker(BaseChecker):
             )
 
     def _check_datetime(self, node):
-        """ Check that a datetime was inferred.
+        """Check that a datetime was inferred.
         If so, emit boolean-datetime warning.
         """
         try:
             inferred = next(node.infer())
         except astroid.InferenceError:
             return
-        if isinstance(inferred, Instance) and inferred.qname() == "datetime.time":
+        if (
+            isinstance(inferred, astroid.Instance)
+            and inferred.qname() == "datetime.time"
+        ):
             self.add_message("boolean-datetime", node=node)
 
     def _check_open_mode(self, node):
@@ -441,7 +443,7 @@ class StdlibChecker(BaseChecker):
             return
 
         name = infer.qname()
-        if isinstance(call_arg, Const):
+        if isinstance(call_arg, astroid.Const):
             emit = False
             if call_arg.value is None:
                 emit = not allow_none
@@ -452,6 +454,15 @@ class StdlibChecker(BaseChecker):
         else:
             self.add_message(message, node=node, args=(name, call_arg.pytype()))
 
+    def deprecated_methods(self):
+        py_vers = sys.version_info[0]
+        deprecated_methods = set()
+        deprecated_methods.update(self.deprecated[0])
+        for since_vers, func_list in self.deprecated[py_vers].items():
+            if since_vers <= sys.version_info:
+                deprecated_methods.update(func_list)
+        return deprecated_methods
+
 
 def register(linter):
     """required method to auto register this checker """
