@@ -69,9 +69,6 @@ from typing import (
 
 import _string
 import astroid
-from astroid import bases as _bases
-from astroid import helpers, scoped_nodes
-from astroid.exceptions import _NonDeducibleTypeHierarchy
 
 from pylint.constants import PY310_PLUS
 
@@ -231,44 +228,44 @@ PYMETHODS = set(SPECIAL_METHODS_PARAMS)
 
 SUBSCRIPTABLE_CLASSES_PEP585 = frozenset(
     (
-        "tuple",
-        "list",
-        "dict",
-        "set",
-        "frozenset",
-        "type",
-        "deque",  # collections
-        "defaultdict",
-        "OrderedDict",
-        "Counter",
-        "ChainMap",
-        "Awaitable",  # collections.abc
-        "Coroutine",
-        "AsyncIterable",
-        "AsyncIterator",
-        "AsyncGenerator",
-        "Iterable",
-        "Iterator",
-        "Generator",
-        "Reversible",
-        "Container",
-        "Collection",
-        "Callable",
-        "Set # typing.AbstractSet",
-        "MutableSet",
-        "Mapping",
-        "MutableMapping",
-        "Sequence",
-        "MutableSequence",
-        "ByteString",
-        "MappingView",
-        "KeysView",
-        "ItemsView",
-        "ValuesView",
-        "AbstractContextManager",  # contextlib
-        "AbstractAsyncContextManager",
-        "Pattern",  # re
-        "Match",
+        "builtins.tuple",
+        "builtins.list",
+        "builtins.dict",
+        "builtins.set",
+        "builtins.frozenset",
+        "builtins.type",
+        "collections.deque",
+        "collections.defaultdict",
+        "collections.OrderedDict",
+        "collections.Counter",
+        "collections.ChainMap",
+        "_collections_abc.Awaitable",
+        "_collections_abc.Coroutine",
+        "_collections_abc.AsyncIterable",
+        "_collections_abc.AsyncIterator",
+        "_collections_abc.AsyncGenerator",
+        "_collections_abc.Iterable",
+        "_collections_abc.Iterator",
+        "_collections_abc.Generator",
+        "_collections_abc.Reversible",
+        "_collections_abc.Container",
+        "_collections_abc.Collection",
+        "_collections_abc.Callable",
+        "_collections_abc.Set # typing.AbstractSet",
+        "_collections_abc.MutableSet",
+        "_collections_abc.Mapping",
+        "_collections_abc.MutableMapping",
+        "_collections_abc.Sequence",
+        "_collections_abc.MutableSequence",
+        "_collections_abc.ByteString",
+        "_collections_abc.MappingView",
+        "_collections_abc.KeysView",
+        "_collections_abc.ItemsView",
+        "_collections_abc.ValuesView",
+        "contextlib.AbstractContextManager",
+        "contextlib.AbstractAsyncContextManager",
+        "re.Pattern",
+        "re.Match",
     )
 )
 
@@ -460,7 +457,11 @@ def is_func_decorator(node: astroid.node_classes.NodeNG) -> bool:
             return True
         if parent.is_statement or isinstance(
             parent,
-            (astroid.Lambda, scoped_nodes.ComprehensionScope, scoped_nodes.ListComp),
+            (
+                astroid.Lambda,
+                astroid.scoped_nodes.ComprehensionScope,
+                astroid.scoped_nodes.ListComp,
+            ),
         ):
             break
         parent = parent.parent
@@ -1137,7 +1138,7 @@ def _supports_protocol(
             return True
 
     if (
-        isinstance(value, _bases.Proxy)
+        isinstance(value, astroid.bases.Proxy)
         and isinstance(value._proxied, astroid.BaseInstance)
         and has_known_bases(value._proxied)
     ):
@@ -1353,11 +1354,8 @@ def is_class_subscriptable_pep585_with_postponed_evaluation_enabled(
         parent_node = parent_node.parent
         if isinstance(parent_node, astroid.Module):
             return False
-    if value.name in SUBSCRIPTABLE_CLASSES_PEP585:
+    if value.qname() in SUBSCRIPTABLE_CLASSES_PEP585:
         return True
-    for name in value.basenames:
-        if name in SUBSCRIPTABLE_CLASSES_PEP585:
-            return True
     return False
 
 
@@ -1373,9 +1371,9 @@ def is_subclass_of(child: astroid.ClassDef, parent: astroid.ClassDef) -> bool:
 
     for ancestor in child.ancestors():
         try:
-            if helpers.is_subtype(ancestor, parent):
+            if astroid.helpers.is_subtype(ancestor, parent):
                 return True
-        except _NonDeducibleTypeHierarchy:
+        except astroid.exceptions._NonDeducibleTypeHierarchy:
             continue
     return False
 
@@ -1435,3 +1433,44 @@ def is_classdef_type(node: astroid.ClassDef) -> bool:
         if isinstance(base, astroid.Name) and base.name == "type":
             return True
     return False
+
+
+def is_attribute_typed_annotation(
+    node: Union[astroid.ClassDef, astroid.Instance], attr_name: str
+) -> bool:
+    """Test if attribute is typed annotation in current node
+    or any base nodes.
+    """
+    attribute = node.locals.get(attr_name, [None])[0]
+    if (
+        attribute
+        and isinstance(attribute, astroid.AssignName)
+        and isinstance(attribute.parent, astroid.AnnAssign)
+    ):
+        return True
+    for base in node.bases:
+        inferred = safe_infer(base)
+        if (
+            inferred
+            and isinstance(inferred, astroid.ClassDef)
+            and is_attribute_typed_annotation(inferred, attr_name)
+        ):
+            return True
+    return False
+
+
+def is_class_var(node: astroid.AssignName) -> bool:
+    """Test if node has `ClassVar` annotation."""
+    if not isinstance(node.parent, astroid.AnnAssign):
+        return False
+    annotation = node.parent.annotation
+    if isinstance(annotation, astroid.Subscript):
+        annotation = annotation.value
+    if (
+        isinstance(annotation, astroid.Name)
+        and annotation.name == "ClassVar"
+        or isinstance(annotation, astroid.Attribute)
+        and annotation.attrname == "ClassVar"
+    ):
+        return True
+    return False
