@@ -32,6 +32,7 @@
 # Copyright (c) 2018 Sushobhit <31987769+sushobhit27@users.noreply.github.com>
 # Copyright (c) 2018 Reverb C <reverbc@users.noreply.github.com>
 # Copyright (c) 2018 Nick Drozd <nicholasdrozd@gmail.com>
+# Copyright (c) 2020 Peter Kolbus <peter.kolbus@gmail.com>
 # Copyright (c) 2020 Damien Baty <damien.baty@polyconseil.fr>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -46,7 +47,7 @@ from pylint.utils.file_state import FileState
 from pylint.utils.utils import (
     HAS_ISORT_5,
     IsortDriver,
-    _basename_in_blacklist_re,
+    _basename_in_ignore_list_re,
     _check_csv,
     _format_option_value,
     _splitstrip,
@@ -69,7 +70,7 @@ __all__ = [
     "ASTWalker",
     "HAS_ISORT_5",
     "IsortDriver",
-    "_basename_in_blacklist_re",
+    "_basename_in_ignore_list_re",
     "_check_csv",
     "_format_option_value",
     "_splitstrip",
